Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(59)

Unified Diff: webrtc/logging/rtc_event_log/rtc_event_log_parser.h

Issue 2856063003: Replace AudioSendStream::Config with rtclog::StreamConfig. (Closed)
Patch Set: Rebased Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webrtc/logging/rtc_event_log/rtc_event_log_parser.h
diff --git a/webrtc/logging/rtc_event_log/rtc_event_log_parser.h b/webrtc/logging/rtc_event_log/rtc_event_log_parser.h
index d5aee967667e3abbbc426b5999cd6371dc8d4629..966f00dfe031132ec9592190694bfbb3d01358b9 100644
--- a/webrtc/logging/rtc_event_log/rtc_event_log_parser.h
+++ b/webrtc/logging/rtc_event_log/rtc_event_log_parser.h
@@ -126,9 +126,9 @@ class ParsedRtcEventLog {
// Only the fields that are stored in the protobuf will be written.
void GetAudioReceiveConfig(size_t index, rtclog::StreamConfig* config) const;
// Reads a config event to a (non-NULL) AudioSendStream::Config struct.
// Only the fields that are stored in the protobuf will be written.
- void GetAudioSendConfig(size_t index, AudioSendStream::Config* config) const;
+ void GetAudioSendConfig(size_t index, rtclog::StreamConfig* config) const;
// Reads the SSRC from the audio playout event at |index|. The SSRC is stored
// in the output parameter ssrc. The output parameter can be set to nullptr
« no previous file with comments | « webrtc/logging/rtc_event_log/rtc_event_log2text.cc ('k') | webrtc/logging/rtc_event_log/rtc_event_log_parser.cc » ('j') | no next file with comments »
@@ -126,9 +126,9 @@ class ParsedRtcEventLog {
// Only the fields that are stored in the protobuf will be written.
void GetAudioReceiveConfig(size_t index, rtclog::StreamConfig* config) const;
- // Reads a config event to a (non-NULL) AudioSendStream::Config struct.
+ // Reads a config event to a (non-NULL) StreamConfig struct.
// Only the fields that are stored in the protobuf will be written.

Powered by Google App Engine
This is Rietveld 408576698